@@ -611,6 +611,7 @@ module.exports = {
 	"9.4.1": "83.0.4103.122",
 	"9.4.2": "83.0.4103.122",
 	"9.4.3": "83.0.4103.122",
+	"9.4.4": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
@@ -704,6 +705,9 @@ module.exports = {
 	"10.3.0": "85.0.4183.121",
 	"10.3.1": "85.0.4183.121",
 	"10.3.2": "85.0.4183.121",
+	"10.4.0": "85.0.4183.121",
+	"10.4.1": "85.0.4183.121",
+	"10.4.2": "85.0.4183.121",
 	"11.0.0-beta.1": "86.0.4234.0",
 	"11.0.0-beta.3": "86.0.4234.0",
 	"11.0.0-beta.4": "86.0.4234.0",
@@ -773,6 +777,10 @@ module.exports = {
 	"11.2.1": "87.0.4280.141",
 	"11.2.2": "87.0.4280.141",
 	"11.2.3": "87.0.4280.141",
+	"11.3.0": "87.0.4280.141",
+	"11.4.0": "87.0.4280.141",
+	"11.4.1": "87.0.4280.141",
+	"11.4.2": "87.0.4280.141",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -793,6 +801,13 @@ module.exports = {
 	"12.0.0-beta.22": "89.0.4388.2",
 	"12.0.0-beta.23": "89.0.4388.2",
 	"12.0.0-beta.24": "89.0.4388.2",
+	"12.0.0-beta.25": "89.0.4388.2",
+	"12.0.0-beta.26": "89.0.4388.2",
+	"12.0.0-beta.27": "89.0.4389.23",
+	"12.0.0-beta.28": "89.0.4389.23",
+	"12.0.0-beta.29": "89.0.4389.23",
+	"12.0.0-beta.30": "89.0.4389.58",
+	"12.0.0-beta.31": "89.0.4389.58",
 	"12.0.0-nightly.20200827": "86.0.4234.0",
 	"12.0.0-nightly.20200831": "86.0.4234.0",
 	"12.0.0-nightly.20200902": "86.0.4234.0",
@@ -815,6 +830,18 @@ module.exports = {
 	"12.0.0-nightly.20201111": "88.0.4306.0",
 	"12.0.0-nightly.20201112": "88.0.4306.0",
 	"12.0.0-nightly.20201116": "88.0.4324.0",
+	"12.0.0": "89.0.4389.69",
+	"12.0.1": "89.0.4389.82",
+	"12.0.2": "89.0.4389.90",
+	"13.0.0-beta.2": "90.0.4402.0",
+	"13.0.0-beta.3": "90.0.4402.0",
+	"13.0.0-beta.4": "90.0.4415.0",
+	"13.0.0-beta.5": "90.0.4415.0",
+	"13.0.0-beta.6": "90.0.4415.0",
+	"13.0.0-beta.7": "90.0.4415.0",
+	"13.0.0-beta.8": "90.0.4415.0",
+	"13.0.0-beta.9": "90.0.4415.0",
+	"13.0.0-beta.11": "90.0.4415.0",
 	"13.0.0-nightly.20201119": "89.0.4328.0",
 	"13.0.0-nightly.20201123": "89.0.4328.0",
 	"13.0.0-nightly.20201124": "89.0.4328.0",
@@ -853,5 +880,37 @@ module.exports = {
 	"13.0.0-nightly.20210205": "89.0.4389.0",
 	"13.0.0-nightly.20210208": "89.0.4389.0",
 	"13.0.0-nightly.20210209": "89.0.4389.0",
-	"13.0.0-nightly.20210210": "90.0.4402.0"
+	"13.0.0-nightly.20210210": "90.0.4402.0",
+	"13.0.0-nightly.20210211": "90.0.4402.0",
+	"13.0.0-nightly.20210212": "90.0.4402.0",
+	"13.0.0-nightly.20210216": "90.0.4402.0",
+	"13.0.0-nightly.20210217": "90.0.4402.0",
+	"13.0.0-nightly.20210218": "90.0.4402.0",
+	"13.0.0-nightly.20210219": "90.0.4402.0",
+	"13.0.0-nightly.20210222": "90.0.4402.0",
+	"13.0.0-nightly.20210225": "90.0.4402.0",
+	"13.0.0-nightly.20210226": "90.0.4402.0",
+	"13.0.0-nightly.20210301": "90.0.4402.0",
+	"13.0.0-nightly.20210302": "90.0.4402.0",
+	"13.0.0-nightly.20210303": "90.0.4402.0",
+	"14.0.0-nightly.20210304": "90.0.4402.0",
+	"14.0.0-nightly.20210305": "90.0.4415.0",
+	"14.0.0-nightly.20210308": "90.0.4415.0",
+	"14.0.0-nightly.20210309": "90.0.4415.0",
+	"14.0.0-nightly.20210311": "90.0.4415.0",
+	"14.0.0-nightly.20210315": "90.0.4415.0",
+	"14.0.0-nightly.20210316": "90.0.4415.0",
+	"14.0.0-nightly.20210317": "90.0.4415.0",
+	"14.0.0-nightly.20210318": "90.0.4415.0",
+	"14.0.0-nightly.20210319": "90.0.4415.0",
+	"14.0.0-nightly.20210323": "90.0.4415.0",
+	"14.0.0-nightly.20210324": "90.0.4415.0",
+	"14.0.0-nightly.20210325": "90.0.4415.0",
+	"14.0.0-nightly.20210326": "90.0.4415.0",
+	"14.0.0-nightly.20210329": "90.0.4415.0",
+	"14.0.0-nightly.20210330": "90.0.4415.0",
+	"14.0.0-nightly.20210331": "91.0.4448.0",
+	"14.0.0-nightly.20210401": "91.0.4448.0",
+	"14.0.0-nightly.20210402": "91.0.4448.0",
+	"14.0.0-nightly.20210406": "91.0.4448.0"
 };
\ No newline at end of file
